<!--invar:critical-->
legacy critical block
<!--/invar:critical-->
<!--invar:managed-->
legacy managed block
<!--/invar:managed-->

User heading
TEAM_NOTE=keep-me-byte-stable

<!--invar:user-->
custom user settings
<!--/invar:user-->
